@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2003,2005,2006,2007,2008
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2003,2005,2006,2007,2008,2009
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -80,7 +80,6 @@ OOP _gst_abstract_namespace_class = NULL;
 OOP _gst_array_class = NULL;
 OOP _gst_arrayed_collection_class = NULL;
 OOP _gst_association_class = NULL;
-OOP _gst_bag_class = NULL;
 OOP _gst_behavior_class = NULL;
 OOP _gst_binding_dictionary_class = NULL;
 OOP _gst_block_closure_class = NULL;
@@ -105,7 +104,6 @@ OOP _gst_context_part_class = NULL;
 OOP _gst_continuation_class = NULL;
 OOP _gst_date_class = NULL;
 OOP _gst_deferred_variable_binding_class = NULL;
-OOP _gst_delay_class = NULL;
 OOP _gst_dictionary_class = NULL;
 OOP _gst_directed_message_class = NULL;
 OOP _gst_false_class = NULL;
@@ -133,7 +131,6 @@ OOP _gst_linked_list_class = NULL;
 OOP _gst_lookup_key_class = NULL;
 OOP _gst_lookup_table_class = NULL;
 OOP _gst_magnitude_class = NULL;
-OOP _gst_mapped_collection_class = NULL;
 OOP _gst_memory_class = NULL;
 OOP _gst_message_class = NULL;
 OOP _gst_metaclass_class = NULL;
@@ -156,7 +153,6 @@ OOP _gst_security_policy_class = NULL;
 OOP _gst_semaphore_class = NULL;
 OOP _gst_sequenceable_collection_class = NULL;
 OOP _gst_set_class = NULL;
-OOP _gst_shared_queue_class = NULL;
 OOP _gst_small_integer_class = NULL;
 OOP _gst_smalltalk_dictionary = NULL;
 OOP _gst_sorted_collection_class = NULL;
@@ -201,6 +197,12 @@ static ssize_t identity_dictionary_find_key (OOP identityDictionaryOOP,
 static size_t identity_dictionary_find_key_or_nil (OOP identityDictionaryOOP,
 						   OOP keyOOP);
 
+/* assume the value is an integer already or key does not exist, increase the
+   value by inc or set the value to inc */
+static int _gst_identity_dictionary_at_inc (OOP identityDictionaryOOP,
+                                            OOP keyOOP,
+                                            int inc);
+
 /* Create a new instance of CLASSOOP (an IdentityDictionary subclass)
    and answer it.  */
 static OOP identity_dictionary_new (OOP classOOP,
@@ -515,14 +517,6 @@ static const class_definition class_info[] = {
    "DefaultSortBlock",
    NULL },
 
-  {&_gst_bag_class, &_gst_collection_class,
-   GST_ISP_FIXED, false, 1,
-   "Bag", "contents", NULL, NULL },
-
-  {&_gst_mapped_collection_class, &_gst_collection_class,
-   GST_ISP_FIXED, false, 2,
-   "MappedCollection", "domain map", NULL, NULL },
-
   {&_gst_hashed_collection_class, &_gst_collection_class,
    GST_ISP_POINTER, false, 1,
    "HashedCollection", "tally", NULL, NULL },
@@ -568,7 +562,7 @@ static const class_definition class_info[] = {
    "WeakValueIdentityDictionary", NULL, NULL, NULL },
 
   {&_gst_identity_dictionary_class, &_gst_lookup_table_class,
-   GST_ISP_POINTER, false, 0,
+   GST_ISP_POINTER, true, 0,
    "IdentityDictionary", NULL, NULL, NULL },
 
   {&_gst_method_dictionary_class, &_gst_lookup_table_class,
@@ -647,15 +641,6 @@ static const class_definition class_info[] = {
    "processLists activeProcess idleTasks processTimeslice gcSemaphore gcArray",
    NULL, NULL },
 
-  {&_gst_delay_class, &_gst_object_class,
-   GST_ISP_FIXED, false, 2,
-   "Delay", "resumptionTime delayDuration",
-   "Queue TimeoutSem MutexSem DelayProcess IdleProcess ActiveDelay DelayEvent", NULL },
-
-  {&_gst_shared_queue_class, &_gst_object_class,
-   GST_ISP_FIXED, false, 3,
-   "SharedQueue", "queueSem valueReady queue", NULL, NULL },
-
   /* Change this, classDescription, or gst_class, and you must change
      the implementaion of new_metaclass some */
   {&_gst_behavior_class, &_gst_object_class,
@@ -729,7 +714,7 @@ static const class_definition class_info[] = {
    NULL, NULL },
 
   {&_gst_c_callback_descriptor_class, &_gst_c_callable_class,
-   GST_ISP_ULONG, false, 1,
+   GST_ISP_ULONG, true, 1,
    "CCallbackDescriptor",
    "block",
    NULL, NULL },
@@ -1032,7 +1017,8 @@ init_smalltalk_dictionary (void)
   for (i = 0; i < numFeatures; i++)
     featuresArray->data[i] = _gst_intern_string (feature_strings[i]);
 
-  sprintf (fullVersionString, "GNU Smalltalk version %s", VERSION);
+  sprintf (fullVersionString, "GNU Smalltalk version %s",
+	   VERSION PACKAGE_GIT_REVISION);
 
   add_smalltalk ("Smalltalk", _gst_smalltalk_dictionary);
   add_smalltalk ("Version", _gst_string_new (fullVersionString));
@@ -1092,6 +1078,8 @@ init_runtime_objects (void)
   add_smalltalk ("SystemKernelPath", relocate_path_oop (KERNEL_PATH));
   add_smalltalk ("ModulePath", relocate_path_oop (MODULE_PATH));
   add_smalltalk ("LibexecPath", relocate_path_oop (LIBEXEC_PATH));
+  add_smalltalk ("Prefix", relocate_path_oop (PREFIX));
+  add_smalltalk ("ExecPrefix", relocate_path_oop (EXEC_PREFIX));
   add_smalltalk ("ImageFilePath", _gst_string_new (_gst_image_file_path));
   add_smalltalk ("ExecutableFileName", _gst_string_new (_gst_executable_path));
   add_smalltalk ("ImageFileName", _gst_string_new (_gst_binary_image_name));
@@ -1362,11 +1350,9 @@ prepare_primitive_numbers_table ()
       symbolOOP = _gst_intern_string (pte->name);
       valueOOP = dictionary_at (primitivesDictionaryOOP, symbolOOP);
 
+      /* Do nothing if the primitive is unknown to the image.  */
       if (IS_NIL (valueOOP))
-        {
-          _gst_errorf ("bad primitive name");
-          continue;
-        }
+        continue;
 
       old_index = TO_INT (valueOOP);
       _gst_set_primitive_attributes (old_index, pte);
@@ -1753,7 +1739,7 @@ _gst_identity_dictionary_at_put (OOP identityDictionaryOOP,
      if the key is present in the dictionary (because it will most
      likely resolve some collisions and make things faster).  */
 
-  if UNCOMMON (TO_INT (identityDictionary->tally) >
+  if UNCOMMON (TO_INT (identityDictionary->tally) >=
       	       TO_INT (identityDictionary->objSize) * 3 / 8)
     identityDictionary =
       _gst_grow_identity_dictionary (identityDictionaryOOP);
@@ -2166,7 +2152,7 @@ _gst_set_file_stream_file (OOP fileStreamOOP,
   if (buffered)
     {
       char buffer[1024];
-      memzero (buffer, sizeof (buffer));
+      memset (buffer, 0, sizeof (buffer));
       fileStream->collection =
 	_gst_counted_string_new (buffer, sizeof (buffer));
       fileStream->ptr = FROM_INT (1);
@@ -2181,3 +2167,83 @@ _gst_set_file_stream_file (OOP fileStreamOOP,
     isPipe == -1 ? _gst_nil_oop :
     isPipe ? _gst_true_oop : _gst_false_oop;
 }
+
+/* Profiling callback.  The profiler use a simple data structure
+   to store the cost and the call graph, which is a 2 level
+   IdentityDictionary. First level keys are the CompiledMethod or
+   CompiledBlock, and the second level key is the CompiledMethod or
+   CompiledBlock that it calls. Values are the number of calls made. There
+   is a special key "true" in the second level whose corresponding value
+   is the accumulative cost for this method.  */
+
+void 
+_gst_record_profile (OOP oldMethod, OOP newMethod, int ipOffset)
+{
+  OOP profile;
+  inc_ptr incPtr;
+
+  /* Protect oldMethod from GC here to avoid complicating the fast path
+     in interp-bc.inl.  */
+  incPtr = INC_SAVE_POINTER ();
+  INC_ADD_OOP (oldMethod);
+
+  profile = _gst_identity_dictionary_at (_gst_raw_profile, oldMethod);
+  if UNCOMMON (IS_NIL (profile))
+    {
+      profile = identity_dictionary_new (_gst_identity_dictionary_class, 6);
+      _gst_identity_dictionary_at_put (_gst_raw_profile, oldMethod, 
+                                       profile);
+    }
+
+  _gst_identity_dictionary_at_inc (profile, _gst_true_oop, 
+                                   _gst_bytecode_counter
+				   - _gst_saved_bytecode_counter);
+  _gst_saved_bytecode_counter = _gst_bytecode_counter;
+
+  /* if ipOffset is 0 then it is a callin and not a return, so we also record 
+     the call.  */
+  if (ipOffset == 0) 
+    _gst_identity_dictionary_at_inc (profile, newMethod, 1);
+
+  INC_RESTORE_POINTER (incPtr);
+}
+
+/* Assume the value for KEYOOP is an integer already or the key does not exist;
+   increase the value by INC or set it to INC if it does not exist.  */
+int
+_gst_identity_dictionary_at_inc (OOP identityDictionaryOOP,
+				 OOP keyOOP,
+				 int inc)
+{
+  gst_identity_dictionary identityDictionary;
+  intptr_t index;
+  int oldValue;
+
+  identityDictionary =
+    (gst_identity_dictionary) OOP_TO_OBJ (identityDictionaryOOP);
+
+  /* Never make dictionaries too full! For simplicity, we do this even
+     if the key is present in the dictionary (because it will most
+     likely resolve some collisions and make things faster).  */
+
+  if UNCOMMON (TO_INT (identityDictionary->tally) >=
+      	       TO_INT (identityDictionary->objSize) * 3 / 8)
+    identityDictionary =
+      _gst_grow_identity_dictionary (identityDictionaryOOP);
+
+  index =
+    identity_dictionary_find_key_or_nil (identityDictionaryOOP, keyOOP);
+
+  if UNCOMMON (IS_NIL (identityDictionary->keys[index - 1]))
+    {
+      identityDictionary->tally = INCR_INT (identityDictionary->tally);
+      oldValue = 0;
+    }
+  else 
+    oldValue = TO_INT(identityDictionary->keys[index]);
+  
+  identityDictionary->keys[index - 1] = keyOOP;
+  identityDictionary->keys[index] = FROM_INT(inc+oldValue);
+
+  return (oldValue);
+}
