@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2006,2007,2008
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2006,2007,2008,2009
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -301,6 +301,14 @@ extern OOP _gst_self
 extern OOP _gst_this_context_oop 
   ATTRIBUTE_HIDDEN;
 
+/* The OOP for an IdentityDictionary that stores the raw profile. */
+extern OOP _gst_raw_profile
+  ATTRIBUTE_HIDDEN;
+
+/* A bytecode counter value used while profiling. */
+extern unsigned long _gst_saved_bytecode_counter
+  ATTRIBUTE_HIDDEN;
+
 /* The type used to hold the instruction pointer.  For the JIT, this
    is an offset from a location which is deemed the `base' of
    native-compiled methods (because this way it will fit in a
@@ -386,6 +394,10 @@ extern void _gst_init_interpreter (void)
 extern void _gst_empty_context_pool (void) 
   ATTRIBUTE_HIDDEN;
 
+/* Return whether there are pending asynchronous calls.  */
+extern mst_Boolean _gst_have_pending_async_calls (void)
+  ATTRIBUTE_HIDDEN;
+
 /* Set up so that FUNC will be called, with ARGOOP as its argument,
    as soon as the next sequence point is reached.  */
 extern void _gst_async_call (void (*func) (OOP),
