@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1991, 2002, 2006, 2007, 2008 Free Software Foundation, Inc.
+ * Copyright 1991, 2002, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
  *
  * This file is derived from an absurdly old version of the GNU MP Library.
  *
@@ -41,7 +41,7 @@
 
 /* Zero NLIMBS *limbs* AT DST.  */
 #define MPN_ZERO(DST, NLIMBS) \
-  memzero((DST), (NLIMBS) * SIZEOF_MP_LIMB_T)
+  memset((DST), 0, (NLIMBS) * SIZEOF_MP_LIMB_T)
 
 /* Initialize the gst_mpz X with space for NLIMBS limbs.
    X should be a temporary variable, and it will be automatically
@@ -879,8 +879,8 @@ _gst_mpz_sub (gst_mpz *w, const gst_mpz *u, const gst_mpz *v)
   w->size = wsize;
 }
 
-double
-_gst_mpz_get_d(const gst_mpz *mpz)
+mst_Boolean
+_gst_mpz_get_d(const gst_mpz *mpz, double *p_d)
 {
   double d, old;
   int n;
@@ -899,14 +899,15 @@ _gst_mpz_get_d(const gst_mpz *mpz)
 
       if (d - old < mpz->d[n])
 	/* Lost some bytes of precision, exit now.  */
-	return ldexp (d, 8 * SIZEOF_MP_LIMB_T * n);
+	return false;
     }
 
-  return d;
+  *p_d = d;
+  return true;
 }
 
-long double
-_gst_mpz_get_ld(const gst_mpz *mpz)
+mst_Boolean
+_gst_mpz_get_ld(const gst_mpz *mpz, long double *p_ld)
 {
   long double d, old;
   int n;
@@ -925,10 +926,11 @@ _gst_mpz_get_ld(const gst_mpz *mpz)
 
       if (d - old < mpz->d[n])
 	/* Lost some bytes of precision, exit now.  */
-	return ldexpl (d, 8 * SIZEOF_MP_LIMB_T * n);
+	return false;
     }
 
-  return d;
+  *p_ld = d;
+  return true;
 }
 
 void
@@ -1511,13 +1513,21 @@ _gst_mpz_xor (gst_mpz *res, const gst_mpz *op1, const gst_mpz *op2)
   }
 }
 
+#if __GNU_MP_VERSION >= 5
+extern void __gmpn_divexact (mp_ptr, mp_srcptr, mp_size_t, mp_srcptr, mp_size_t);
+#endif
+
 void
 _gst_mpz_divexact (gst_mpz *quot, const gst_mpz *num, const gst_mpz *den)
 {
-  mp_ptr qp, tp;
+  mp_ptr qp;
   mp_srcptr np, dp;
-  mp_size_t nsize, dsize, qsize, d_zero_limbs;
+  mp_size_t nsize, dsize, qsize;
+#if __GNU_MP_VERSION < 5
+  mp_ptr tp;
+  mp_size_t d_zero_limbs;
   int d_zero_bits;
+#endif
 
   nsize = ABS (num->size);
   dsize = ABS (den->size);
@@ -1540,6 +1550,7 @@ _gst_mpz_divexact (gst_mpz *quot, const gst_mpz *num, const gst_mpz *den)
       return;
     }
 
+#if __GNU_MP_VERSION < 5
   /* Avoid quadratic behaviour, but do it conservatively.  */
   if (nsize - dsize > 1500)
     {
@@ -1558,6 +1569,7 @@ _gst_mpz_divexact (gst_mpz *quot, const gst_mpz *num, const gst_mpz *den)
   dsize -= d_zero_limbs;
   np += d_zero_limbs;
   nsize -= d_zero_limbs;
+#endif
 
   /* Allocate where we place the result.  It must be nsize limbs big
      because it also acts as a temporary area.  */
@@ -1565,6 +1577,7 @@ _gst_mpz_divexact (gst_mpz *quot, const gst_mpz *num, const gst_mpz *den)
     gst_mpz_realloc (quot, nsize);
   qp = quot->d;
 
+#if __GNU_MP_VERSION < 5
   if (d_zero_bits != 0)
     {
       tp = (mp_ptr) alloca (dsize * SIZEOF_MP_LIMB_T);
@@ -1577,9 +1590,14 @@ _gst_mpz_divexact (gst_mpz *quot, const gst_mpz *num, const gst_mpz *den)
     }
   else
     MPN_COPY(qp, np, nsize);
+#endif
 
   qsize = nsize - dsize + 1;
+#if __GNU_MP_VERSION < 5
   mpn_bdivmod (qp, qp, nsize, dp, dsize, qsize * GMP_NUMB_BITS);
+#else
+  __gmpn_divexact (qp, np, nsize, dp, dsize);
+#endif
   quot->size = (num->size ^ den->size) >= 0 ? qsize : -qsize;
 }
 
